@@ -10,7 +10,7 @@ module_info = ModuleInfo(
     label="Parking (envelope)",
     pg_updater=multi_sensor_pg_updater(PGUpdater),
     processing_config_class=ProcessingConfiguration,
-    module_family=ModuleFamily.DETECTOR,
+    module_family=ModuleFamily.EXAMPLE,
     sensor_config_class=get_sensor_config,
     processor=multi_sensor_processor(Processor),
     multi_sensor=True,
