@@ -24,7 +24,63 @@ class SubsweepProxyProperty(utils.ProxyProperty[T]):
 
 
 class SensorConfig:
-    """Configuration of a single sensor"""
+    """Sensor configuration
+
+    The sensor config represents a 1-1 mapping to the RSS service config.
+
+    By default, the sensor config holds a single :class:`SubsweepConfig`. The parameters defined by
+    the subsweep config, like :attr:`start_point`, can be accessed via the sensor config. If
+    multiple subsweeps are used, those parameters must be accessed via their respective subsweep
+    configs.
+
+    For example, a sensor config can be created like this:
+
+    .. code-block:: python
+
+        SensorConfig(sweeps_per_frame=16, start_point=123)
+
+    Note that the :attr:`start_point` is implicitly set in the underlying subsweep config. If you
+    want to explicitly set the subsweep config(s), you can do
+
+    .. code-block:: python
+
+        SensorConfig(
+            sweeps_per_frame=16,
+            subsweeps=[
+                SubsweepConfig(start_point=123),
+            ],
+        )
+
+    Parameters can also be accessed via the class attributes:
+
+    .. code-block:: python
+
+        sensor_config = SensorConfig()
+        sensor_config.sweeps_per_frame = 16
+        sensor_config.start_point = 123
+
+    If you want to use multiple subsweeps with this style of setting/getting the attributes, you
+    can do like this:
+
+    .. code-block:: python
+
+        sensor_config = SensorConfig(num_subsweeps=3)
+        sensor_config.sweeps_per_frame = 16
+        sensor_config.subsweeps[0].start_point = 123
+
+    .. note::
+
+        The sensor config does not control on which sensor it should be run. That is handled by
+        the :class:`SessionConfig`.
+
+    :param subsweeps:
+        The list of subsweeps to initialize with. May not be combined with ``num_subsweeps``.
+    :param num_subsweeps:
+        Initialize with a given number of subsweeps. May not be combined with ``subsweeps``.
+    :raises ValueError: If ``subsweeps`` and ``num_subsweeps`` are both given.
+    :raises ValueError: If the given list of ``subsweeps`` is empty.
+    :raises ValueError: If subsweeps parameters are both given implicitly and via ``subsweeps``.
+    """
 
     _subsweeps: list[SubsweepConfig]
 
@@ -42,6 +98,7 @@ class SensorConfig:
     hwaas = SubsweepProxyProperty[int](SubsweepConfig.hwaas)
     receiver_gain = SubsweepProxyProperty[int](SubsweepConfig.receiver_gain)
     enable_tx = SubsweepProxyProperty[bool](SubsweepConfig.enable_tx)
+    enable_loopback = SubsweepProxyProperty[bool](SubsweepConfig.enable_loopback)
     phase_enhancement = SubsweepProxyProperty[bool](SubsweepConfig.phase_enhancement)
     prf = SubsweepProxyProperty[PRF](SubsweepConfig.prf)
 
@@ -63,6 +120,7 @@ class SensorConfig:
         hwaas: Optional[int] = None,
         receiver_gain: Optional[int] = None,
         enable_tx: Optional[bool] = None,
+        enable_loopback: Optional[bool] = None,
         phase_enhancement: Optional[bool] = None,
         prf: Optional[PRF] = None,
     ) -> None:
@@ -81,6 +139,7 @@ class SensorConfig:
             and hwaas is None
             and receiver_gain is None
             and enable_tx is None
+            and enable_loopback is None
             and phase_enhancement is None
             and prf is None
         )
@@ -123,6 +182,8 @@ class SensorConfig:
             self.receiver_gain = receiver_gain
         if enable_tx is not None:
             self.enable_tx = enable_tx
+        if enable_loopback is not None:
+            self.enable_loopback = enable_loopback
         if phase_enhancement is not None:
             self.phase_enhancement = phase_enhancement
         if prf is not None:
@@ -134,21 +195,24 @@ class SensorConfig:
 
     @property
     def subsweep(self) -> SubsweepConfig:
-        """Convenience attribute for accessing the one and only SubsweepConfig.
+        """Retrieves the sole ``SubsweepConfig``
 
-        :raises: AttributeError if ``num_subsweeps`` != 1
+        :raises AttributeError: If ``num_subsweeps`` != 1
         """
+
         self._assert_single_subsweep()
         return self.subsweeps[0]
 
     @property
     def subsweeps(self) -> list[SubsweepConfig]:
-        """The list of used subsweep configurations."""
+        """The list of subsweep configs"""
+
         return self._subsweeps
 
     @property
     def num_subsweeps(self) -> int:
-        """The number of used subsweep configurations."""
+        """The number of subsweep configs"""
+
         return len(self.subsweeps)
 
     def __eq__(self, other: Any) -> bool:
@@ -183,9 +247,9 @@ class SensorConfig:
         return cls.from_dict(json.loads(json_str))
 
     def validate(self) -> None:
-        """Preforms self-validation.
+        """Performs self-validation and validation of its subsweep configs
 
-        :raises: ``ValueError`` if the config is invalid.
+        :raises ValueError: If anything is invalid.
         """
         # TODO: ValueErrors are the wrong Exception type sub-validators.
         self._validate_continuous_sweep_mode()
@@ -247,10 +311,13 @@ class SensorConfig:
 
     @property
     def sweeps_per_frame(self) -> int:
-        """Sweeps per frame.
+        """Sweeps per frame (SPF)
+
+        The number of sweeps that will be captured in each frame (measurement).
 
         Must be > 0.
         """
+
         return self._sweeps_per_frame
 
     @sweeps_per_frame.setter
@@ -260,11 +327,13 @@ class SensorConfig:
 
     @property
     def sweep_rate(self) -> Optional[float]:
-        """Sweep rate.
+        """Sweep rate
 
-        The sweep rate in Hz. Must be > 0,
-        ``None`` is interpreted as max sweep rate.
+        The sweep rate for sweeps in a frame (measurement).
+
+        In Hz. Must be > 0 or ``None``, where ``None`` is interpreted as max sweep rate.
         """
+
         return self._sweep_rate
 
     @sweep_rate.setter
@@ -276,11 +345,14 @@ class SensorConfig:
 
     @property
     def frame_rate(self) -> Optional[float]:
-        """Frame rate.
+        """Frame rate
 
-        The frame rate in Hz. Must be > 0,
-        ``None`` is interpreted as unlimited.
+        Setting the frame rate to unlimited means that the rate is not limited by the sensor but
+        the rate that the host acknowledge and reads out the measurement data.
+
+        In Hz. Must be > 0 or ``None``, where ``None`` is interpreted as unlimited.
         """
+
         return self._frame_rate
 
     @frame_rate.setter
@@ -292,16 +364,18 @@ class SensorConfig:
 
     @property
     def continuous_sweep_mode(self) -> bool:
-        """Continuous sweep mode.
+        """Continuous sweep mode
 
-        In continuous sweep mode the timing will be identical over all sweeps, not
-        just the sweeps in a frame.
+        In continuous sweep mode the timing will be identical over all sweeps, not just the sweeps
+        in a frame.
 
         Constraints:
-        * Frame rate must be set to unlimited (``None``).
-        * Sweep rate must be set (``> 0``).
-        * Inter frame idle state must be set equal to inter sweep idle state.
+
+        - :attr:`frame_rate` must be set to unlimited (``None``).
+        - :attr:`sweep_rate` must be set (> 0).
+        - :attr:`inter_frame_idle_state` must be set equal to :attr:`inter_sweep_idle_state`.
         """
+
         return self._continuous_sweep_mode
 
     @continuous_sweep_mode.setter
@@ -310,16 +384,16 @@ class SensorConfig:
 
     @property
     def inter_frame_idle_state(self) -> IdleState:
-        """Inter frame idle state.
+        """Inter frame idle state
 
-        The inter frame idle state is the state the sensor idles in
-        between each frame.
+        The inter frame idle state is the state the sensor idles in between each frame.
 
         See also :class:`.config_enums.IdleState`.
 
-        The inter frame idle state of the frame must be deeper or
-        the same as the inter sweep idle state.
+        The :attr:`inter_frame_idle_state` of the frame must be deeper or
+        the same as the :attr:`inter_sweep_idle_state` .
         """
+
         return self._inter_frame_idle_state
 
     @inter_frame_idle_state.setter
@@ -328,13 +402,14 @@ class SensorConfig:
 
     @property
     def inter_sweep_idle_state(self) -> IdleState:
-        """Inter sweep idle state.
+        """Inter sweep idle state
 
         The inter frame idle state is the state the sensor idles in
         between each sweep in a frame.
 
         See also :class:`.config_enums.IdleState`.
         """
+
         return self._inter_sweep_idle_state
 
     @inter_sweep_idle_state.setter
